<div align="center">
  <img src="docs/_static/readme/N3D3-logo.png" alt="N3D3" height="200">
</div>

----------------------------------------------------------------

[![License](https://img.shields.io/badge/license-CeCILL--C-blue.svg)](LICENSE)
[![PyPI version](https://badge.fury.io/py/n3d3.svg)](https://pypi.org/project/n3d3)

N3D3 (for New Neural Network Design, Deployment & Discovery) is CEA LIST's CAD framework for designing and simulating
Deep Neural Network (DNN), and building full DNN-based applications on embedded platforms.
N3D3 is currently an experimental project of N2D2's refactor.
